@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from media_platform.lang.serialization import Deserializable
 from media_platform.metadata.audio_file_metadata import AudioFileMetadata
 from media_platform.metadata.file_metadata import FileMetadata, MediaType
@@ -9,8 +11,7 @@ from media_platform.metadata.video_file_metadata import VideoFileMetadata
 class _FileMetadataDeserializer(Deserializable):
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> FileMetadata
+    def deserialize(cls, data: dict) -> FileMetadata:
         media_type = data['mediaType']
 
         if media_type == MediaType.video:
