@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from media_platform.service.destination import Destination
 from typing import Dict
 
@@ -5,22 +7,16 @@ from media_platform.lang.serialization import Deserializable, Serializable
 
 
 class StreamDVR(Deserializable, Serializable):
-    def __init__(self, destination):
-        # type: (Destination) -> None
-
+    def __init__(self, destination: Destination):
         self.destination = destination
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (Dict) -> StreamDVR
-
+    def deserialize(cls, data: dict) -> StreamDVR:
         destination = Destination.deserialize(data['destination'])
 
         return cls(destination)
 
-    def serialize(self):
-        # type: () -> Dict
-
+    def serialize(self) -> Dict:
         return {
             'destination': self.destination.serialize()
         }
